@@ -1,7 +1,5 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
-# Copyright 2017 Division of Medical Image Computing, German Cancer Research Center (DKFZ)
+# Copyright 2021 Division of Medical Image Computing, German Cancer Research Center (DKFZ)
+# and Applied Computer Vision Lab, Helmholtz Imaging Platform
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 from builtins import range
 
 import numpy as np
@@ -46,7 +43,7 @@ def augment_rot90(sample_data, sample_seg, num_rot=(1, 2, 3), axes=(0, 1, 2)):
     return sample_data, sample_seg
 
 
-def augment_resize(sample_data, sample_seg, target_size, order=3, order_seg=1, cval_seg=0):
+def augment_resize(sample_data, sample_seg, target_size, order=3, order_seg=1):
     """
     Reshapes data (and seg) to target_size
     :param sample_data: np.ndarray or list/tuple of np.ndarrays, must be (c, x, y(, z))) (if list/tuple then each entry
@@ -72,14 +69,14 @@ def augment_resize(sample_data, sample_seg, target_size, order=3, order_seg=1, c
     if sample_seg is not None:
         target_seg = np.ones([sample_seg.shape[0]] + target_size_here)
         for c in range(sample_seg.shape[0]):
-            target_seg[c] = resize_segmentation(sample_seg[c], target_size_here, order_seg, cval_seg)
+            target_seg[c] = resize_segmentation(sample_seg[c], target_size_here, order_seg)
     else:
         target_seg = None
 
     return sample_data, target_seg
 
 
-def augment_zoom(sample_data, sample_seg, zoom_factors, order=3, order_seg=1, cval_seg=0):
+def augment_zoom(sample_data, sample_seg, zoom_factors, order=3, order_seg=1):
     """
     zooms data (and seg) by factor zoom_factors
     :param sample_data: np.ndarray or list/tuple of np.ndarrays, must be (c, x, y(, z))) (if list/tuple then each entry
@@ -108,7 +105,7 @@ def augment_zoom(sample_data, sample_seg, zoom_factors, order=3, order_seg=1, cv
     if sample_seg is not None:
         target_seg = np.ones([sample_seg.shape[0]] + target_shape_here)
         for c in range(sample_seg.shape[0]):
-            target_seg[c] = resize_segmentation(sample_seg[c], target_shape_here, order_seg, cval_seg)
+            target_seg[c] = resize_segmentation(sample_seg[c], target_shape_here, order_seg)
     else:
         target_seg = None
 
@@ -262,14 +259,14 @@ def augment_spatial(data, seg, patch_size, patch_center_dist_from_border=30,
             coords = scale_coords(coords, sc)
             modified_coords = True
 
-        # now find a nice center location
+        # now find a nice center location 
         if modified_coords:
             for d in range(dim):
                 if random_crop:
                     ctr = np.random.uniform(patch_center_dist_from_border[d],
                                             data.shape[d + 2] - patch_center_dist_from_border[d])
                 else:
-                    ctr = int(np.round(data.shape[d + 2] / 2.))
+                    ctr = data.shape[d + 2] / 2. - 0.5
                 coords[d] += ctr
             for channel_id in range(data.shape[1]):
                 data_result[sample_id, channel_id] = interpolate_img(data[sample_id, channel_id], coords, order_data,
@@ -436,7 +433,7 @@ def augment_spatial_2(data, seg, patch_size, patch_center_dist_from_border=30,
                     ctr = np.random.uniform(patch_center_dist_from_border[d],
                                             data.shape[d + 2] - patch_center_dist_from_border[d])
                 else:
-                    ctr = int(np.round(data.shape[d + 2] / 2.))
+                    ctr = data.shape[d + 2] / 2. - 0.5
                 coords[d] += ctr
             for channel_id in range(data.shape[1]):
                 data_result[sample_id, channel_id] = interpolate_img(data[sample_id, channel_id], coords, order_data,
