@@ -1,4 +1,5 @@
-# Copyright 2017 Division of Medical Image Computing, German Cancer Research Center (DKFZ)
+# Copyright 2021 Division of Medical Image Computing, German Cancer Research Center (DKFZ)
+# and Applied Computer Vision Lab, Helmholtz Imaging Platform
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,6 +12,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 from batchgenerators.transforms.abstract_transforms import AbstractTransform
 from batchgenerators.augmentations.spatial_transformations import augment_spatial, augment_spatial_2, \
     augment_channel_translation, \
@@ -56,7 +58,7 @@ class Rot90Transform(AbstractTransform):
 
 
 class ZoomTransform(AbstractTransform):
-    def __init__(self, zoom_factors=1, order=3, order_seg=1, cval_seg=0, concatenate_list=False, data_key="data",
+    def __init__(self, zoom_factors=1, order=3, order_seg=1, concatenate_list=False, data_key="data",
                  label_key="seg"):
         """
         Zooms 'data' (and 'seg') by zoom_factors
@@ -73,7 +75,6 @@ class ZoomTransform(AbstractTransform):
 
         """
         self.concatenate_list = concatenate_list
-        self.cval_seg = cval_seg
         self.order_seg = order_seg
         self.data_key = data_key
         self.label_key = label_key
@@ -102,8 +103,7 @@ class ZoomTransform(AbstractTransform):
             sample_seg = None
             if seg is not None:
                 sample_seg = seg[b]
-            res_data, res_seg = augment_zoom(data[b], sample_seg, self.zoom_factors, self.order, self.order_seg,
-                                             self.cval_seg)
+            res_data, res_seg = augment_zoom(data[b], sample_seg, self.zoom_factors, self.order, self.order_seg)
             results.append((res_data, res_seg))
 
         if concatenate:
@@ -120,7 +120,7 @@ class ZoomTransform(AbstractTransform):
 
 class ResizeTransform(AbstractTransform):
 
-    def __init__(self, target_size, order=3, order_seg=1, cval_seg=0, concatenate_list=False, data_key="data",
+    def __init__(self, target_size, order=3, order_seg=1, concatenate_list=False, data_key="data",
                  label_key="seg"):
         """
         Reshapes 'data' (and 'seg') to target_size
@@ -137,7 +137,6 @@ class ResizeTransform(AbstractTransform):
 
         """
         self.concatenate_list = concatenate_list
-        self.cval_seg = cval_seg
         self.order_seg = order_seg
         self.data_key = data_key
         self.label_key = label_key
@@ -166,8 +165,7 @@ class ResizeTransform(AbstractTransform):
             sample_seg = None
             if seg is not None:
                 sample_seg = seg[b]
-            res_data, res_seg = augment_resize(data[b], sample_seg, self.target_size, self.order, self.order_seg,
-                                               self.cval_seg)
+            res_data, res_seg = augment_resize(data[b], sample_seg, self.target_size, self.order, self.order_seg)
             results.append((res_data, res_seg))
 
         if concatenate:
@@ -191,7 +189,8 @@ class MirrorTransform(AbstractTransform):
 
     """
 
-    def __init__(self, axes=(0, 1, 2), data_key="data", label_key="seg"):
+    def __init__(self, axes=(0, 1, 2), data_key="data", label_key="seg", p_per_sample=1):
+        self.p_per_sample = p_per_sample
         self.data_key = data_key
         self.label_key = label_key
         self.axes = axes
@@ -205,13 +204,14 @@ class MirrorTransform(AbstractTransform):
         seg = data_dict.get(self.label_key)
 
         for b in range(len(data)):
-            sample_seg = None
-            if seg is not None:
-                sample_seg = seg[b]
-            ret_val = augment_mirroring(data[b], sample_seg, axes=self.axes)
-            data[b] = ret_val[0]
-            if seg is not None:
-                seg[b] = ret_val[1]
+            if np.random.uniform() < self.p_per_sample:
+                sample_seg = None
+                if seg is not None:
+                    sample_seg = seg[b]
+                ret_val = augment_mirroring(data[b], sample_seg, axes=self.axes)
+                data[b] = ret_val[0]
+                if seg is not None:
+                    seg[b] = ret_val[1]
 
         data_dict[self.data_key] = data
         if seg is not None:
@@ -484,7 +484,9 @@ class TransposeAxesTransform(AbstractTransform):
     def __init__(self, transpose_any_of_these=(0, 1, 2), data_key="data", label_key="seg", p_per_sample=1):
         '''
         This transform will randomly shuffle the axes of transpose_any_of_these.
-        Requires your patch size to have the same dimension in all spatial axes (like 128x128x128, NOT 128x128x96)!
+        Requires your patch size to have the same dimension in all axes specified in transpose_any_of_these. So if
+        transpose_any_of_these=(0, 1, 2) the shape must be (128x128x128) and cannotbe, for example (128x128x96)
+        (transpose_any_of_these=(0, 1) would be the correct one here)!
         :param transpose_any_of_these: spatial dimensions to transpose, 0=x, 1=y, 2=z. Must be a tuple/list of len>=2
         :param data_key:
         :param label_key:
