@@ -1,4 +1,5 @@
-# Copyright 2017 Division of Medical Image Computing, German Cancer Research Center (DKFZ)
+# Copyright 2021 Division of Medical Image Computing, German Cancer Research Center (DKFZ)
+# and Applied Computer Vision Lab, Helmholtz Imaging Platform
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +14,8 @@
 # limitations under the License.
 
 import copy
+from typing import List, Type, Union, Tuple
+
 import numpy as np
 
 from batchgenerators.augmentations.utils import convert_seg_image_to_one_hot_encoding, \
@@ -440,3 +443,46 @@ class ConvertToChannelLastTransform(AbstractTransform):
                 data = data.transpose(new_ordering)
                 data_dict[k] = data
         return data_dict
+
+
+class OneOfTransform(AbstractTransform):
+    def __init__(self, list_of_transforms: List):
+        """
+        Randomly selects one of the transforms given in list_of_transforms and applies it. Remember that
+        probabilities of the individual transforms for being applied still exist and apply!
+        :param list_of_transforms:
+        """
+        self.list_of_transforms = list_of_transforms
+
+    def __call__(self, **data_dict):
+        i = np.random.choice(len(self.list_of_transforms))
+        return self.list_of_transforms[i](**data_dict)
+
+
+class OneOfTransformPerSample(AbstractTransform):
+    def __init__(self, list_of_transforms: List, relevant_keys: Union[Tuple[str, ...], List[str]],
+                 p: Tuple[float, ...] = None):
+        """
+        For each sample in a batch, randomly select one of the transforms. Difference to OneOfTransform is that
+        OneOfTransform selects a random transform for each batch, so all samples in a batch share that transform
+        :param list_of_transforms:
+        """
+        self.list_of_transforms = list_of_transforms
+        self.relevant_keys = relevant_keys
+        self.p = p
+        if p is not None:
+            assert len(p) == len(list_of_transforms), 'if sampling probabilities are provided there must be one ' \
+                                                      'probability per transform (length of tuples/lists must match)'
+            assert sum(p) == 1, 'probabilities must sum to 1'
+
+    def __call__(self, **data_dict):
+        # for each sample in the batch, construct a new dict using the relevant keys. All entries of relevent_keys are
+        # expected to have the same length
+        some_value = data_dict.get(self.relevant_keys[0])
+        for b in range(len(some_value)):
+            new_dict = {i: data_dict[i][b:b+1] for i in self.relevant_keys}
+            random_transform = np.random.choice(len(self.list_of_transforms), p=self.p)
+            ret = self.list_of_transforms[random_transform](**new_dict)
+            for i in self.relevant_keys:
+                data_dict[i][b] = ret[i]
+        return data_dict
